@@ -10,7 +10,6 @@ from pandas import DataFrame
 
 import cognite.airworkflow.constants as const
 from cognite.airworkflow.model.config import Config
-from cognite.airworkflow.model.project import Project
 from cognite.airworkflow.util import cdf
 
 AIR_INFRA = "airInfra"
@@ -20,9 +19,9 @@ AIR_ROOT_ID = "AIR_root_asset"
 
 
 class ModelAssetHierarchy:
-    def __init__(self, config: Dict[Path, Config], project: Project):
+    def __init__(self, config: Dict[Path, Config], project: str, airInfra: bool = False):
         self.config = config
-
+        self.airInfra = airInfra
         project_info = const.PROJECTS_TO_API_KEYS[project]
         print("Project: " + project_info.name)
         self.client = CogniteClient(
@@ -50,7 +49,7 @@ class ModelAssetHierarchy:
     def _get_asset_hierarchy(self) -> Dict[str, Dict]:
         hierarchy: Dict[str, Dict] = {AIR_MODELS: {}, AIR_INFRA: {}}
         for key, value in self.config.items():
-            if value.air_infrastructure:
+            if self.airInfra:
                 hierarchy[AIR_INFRA].update({key: value.to_dict()})
             else:
                 hierarchy[AIR_MODELS].update({key: value.to_dict()})
