@@ -50,7 +50,7 @@ def handle_delete_functions():
     _, project_to_config = get_master_config()
     for project, config in project_to_config.items():
         function_paths = [functions.get_relative_function_path(p) for p in config]
-        if os.environ["GITLAB_CLIENT"] == "True":
+        if os.getenv("CI_PROJECT_ID") and os.getenv("GITLAB_ACCESS_TOKEN"):
             pr_refs = github.gitlab_open_mrs(str(os.environ["CI_PROJECT_ID"]), str(os.environ["GITLAB_ACCESS_TOKEN"]))
         else:
             pr_refs = github.get_open_pr_refs()
